@@ -310,6 +310,8 @@ instance ToJSON a => ToJSON (CitationItem a) where
 data Citation a =
   Citation { citationId         :: Maybe Text
            , citationNoteNumber :: Maybe Int
+           , citationPrefix     :: Maybe a
+           , citationSuffix     :: Maybe a
            , citationItems      :: [CitationItem a] }
   deriving (Show, Eq, Ord)
 
@@ -323,21 +325,27 @@ instance (FromJSON a, Eq a) => FromJSON (Citation a) where
                                   <*> ((o .: "properties"
                                              >>= (.: "noteIndex"))
                                       <|> pure Nothing)
+                                  <*> o .:? "citationPrefix"
+                                  <*> o .:? "citationSuffix"
                                   <*> o .: "citationItems") v'
-                  <|> Citation Nothing Nothing <$> parseJSON v'
+                  <|> Citation Nothing Nothing Nothing Nothing <$> parseJSON v'
          Nothing -> fail "Empty array") v
    <|>
    withObject "Citation"
      (\o -> Citation <$> o .:? "citationID"
                      <*> o .:? "citationNoteNumber"
+                     <*> o .:? "citationPrefix"
+                     <*> o .:? "citationSuffix"
                      <*> o .: "citationItems") v
    <|>
-   (Citation Nothing Nothing <$> parseJSON v)
+   (Citation Nothing Nothing Nothing Nothing <$> parseJSON v)
 
 instance ToJSON a => ToJSON (Citation a) where
  toJSON c =
    object $
      [ ("citationID", toJSON $ citationId c) | isJust (citationId c) ] ++
+     [ ("citationPrefix", toJSON $ citationPrefix c) | isJust (citationPrefix c) ] ++
+     [ ("citationSuffix", toJSON $ citationSuffix c) | isJust (citationSuffix c) ] ++
      [ ("citationItems" , toJSON $ citationItems c) ] ++
      case citationNoteNumber c of
            Nothing -> []
@@ -550,6 +558,7 @@ data TextCase =
    | CapitalizeAll
    | SentenceCase
    | TitleCase
+   | PreserveCase
    deriving (Show, Eq)
 
 data DisplayStyle =
@@ -1531,6 +1540,11 @@ renderOutput opts (Tagged (TagItem itemtype ident) x)
   | linkCitations opts
   , itemtype /= AuthorOnly
   = addHyperlink ("#ref-" <> unItemId ident) $ renderOutput opts x
+renderOutput opts (Tagged (TagNames _ _ ns) x)
+  -- a hack to ensure that names starting with lowercase don't get
+  -- capitalized in pandoc footnotes: see jgm/pandoc#10983
+  | any hasNonstandardCase ns
+  = addTextCase Nothing PreserveCase $ renderOutput opts x
 renderOutput opts (Tagged _ x) = renderOutput opts x
 renderOutput opts (Formatted f [Linked url xs])
   | linkBibliography opts
@@ -1556,6 +1570,18 @@ renderOutput opts (InNote x) = inNote $
   dropTextWhile (\c -> c == ',' || c == ';' || c == '.' || c == ':') $
   renderOutput opts x
 
+hasNonstandardCase :: Name -> Bool
+hasNonstandardCase name =
+  maybe False startsWithLowercase (nameGiven name) ||
+  maybe False startsWithLowercase (nameFamily name) ||
+  maybe False startsWithLowercase (nameLiteral name)
+ where
+  startsWithLowercase t = case T.uncons t of
+                            Just (c,t')
+                              | isLetter c -> isLower c
+                              | otherwise -> startsWithLowercase t'
+                            Nothing -> False
+
 addDelimiters :: CiteprocOutput a => a -> [a] -> [a]
 addDelimiters delim =
   foldr addDelim []
@@ -1698,7 +1724,7 @@ data Result a =
                     -- each a pair consisting of the item identifier and
                     -- the formatted entry
   , resultWarnings      :: [Text]       -- ^ Warnings from citation processing
-  } deriving (Show, Functor, Traversable, Foldable)
+  } deriving (Eq, Show, Functor, Traversable, Foldable)
 
 instance ToJSON a => ToJSON (Result a) where
   toJSON res = object
